@@ -4,7 +4,7 @@ function (formula = formula(data), data = parent.frame(), burn.in = 1000,
     seed.set = 100, ...) 
 {
     require(survival)
-    require(coda)
+    require(MCMCpack)
     call <- match.call()
     m <- match.call(expand = FALSE)
     temp <- c("", "formula", "data")
@@ -86,14 +86,16 @@ function (formula = formula(data), data = parent.frame(), burn.in = 1000,
         control$n.inter <- 100
     if (control$delta.taylor.miss) 
         control$delta.taylor <- 0.1
-    if (control$haz.global.miss) 
-        control$haz.global <- Inf
     if (control$sigma.lbh.0.miss) 
         control$sigma.lbh.0 <- 100
     if (control$sigma.lbh.1.miss) 
         control$sigma.lbh.1 <- 100
-    if (control$prec.beta.miss) 
-        control$prec.beta <- 1e-04
+    if (control$prec.beta.init.miss) 
+        control$prec.beta.init <- 1e-04
+    if (control$rate.wishart.beta.miss) 
+        control$rate.wishart.beta <- 1e-04
+    if (control$shape.wishart.beta.miss) 
+        control$shape.wishart.beta <- 1e-04
     if (control$rate.sigma.lbh.0.miss) 
         control$rate.sigma.lbh.0 <- 1e-04
     if (control$rate.sigma.lbh.1.miss) 
